/**
 * NoScript - a Firefox extension for whitelist driven safe JavaScript execution
 *
 * Copyright (C) 2005-2023 Giorgio Maone <https://maone.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */


// This script injects ../common/theme.css into content.css after stripping
// ever reference to the extension's URL, except --img-logo turned into a
// data: URL

const fs = require('fs');
const path = require('path');

const themesPath = path.join(__dirname, '..', 'common', 'themes.css');

let themesCSS = fs.readFileSync(themesPath, {encoding: "utf-8"})
  .replace(
    /(--img-logo:.*url\("?)\/(.*\.svg)"?/g, (s, prop, url) => {
    const logoPath = path.join(__dirname, '..', ...url.split("/"));
    return `${prop}"data:image/svg+xml,${
      encodeURIComponent(fs.readFileSync(logoPath))
    }"`
  })
  .replace(/.*\burl\(\.*\/.*\n/g, '')
  .replace(/\/\*[^]*?\*\//g, '')
  .replace(/\n+/g, "\n");

console.log(themesCSS);

const contentPath = path.join(__dirname, 'content.css');
let contentCSS = fs.readFileSync(contentPath, {encoding: "utf-8"});
let updatedCSS = contentCSS
  .replace(
    /\b(THEMES_START\b.*\n)[^]*(\n.*\bTHEMES_END)\b/g,
    `$1${themesCSS}$2`
  );
console.log(updatedCSS);
if (updatedCSS !== contentCSS) {
  console.log(`${contentPath} updated!`);
  fs.writeFileSync(contentPath, updatedCSS);
  process.exit(0);
}
console.log(`Nothing to do with ${contentPath}, already up-to-date.`);
process.exit(1);
